netapp_ontap.models.nvme_namespace_location API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nvme_namespace_location`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NvmeNamespaceLocationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NvmeNamespaceLocation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `namespace: str GET POST`

    The base name component of the NVMe namespace. Valid in POST.
    If properties `name` and `location.namespace` are specified in the same request, they must refer to the base name.
    NVMe namespaces do not support rename. The namespace property is read-only and cannot be set in POST or PATCH. Use the `name` property for POST and PATCH.

    Example: namespace1

  `node: Node GET`

    The node field of the nvme_namespace_location.

  `qtree: Qtree GET POST`

    The qtree field of the nvme_namespace_location.

  `storage_availability_zone: StorageAvailabilityZone GET`

    The storage_availability_zone field of the nvme_namespace_location.

  `volume: Volume GET POST`

    The volume field of the nvme_namespace_location.